@@ -1,9 +1,8 @@
 import logging
 import os
-from typing import List, Dict
+from typing import List
 
 from litellm import get_llm_provider
-from openai.types.beta.threads.run_submit_tool_outputs_params import ToolOutput
 
 from astra_assistants import patch, OpenAI
 from astra_assistants.astra_assistants_event_handler import AstraEventHandler
@@ -13,18 +12,21 @@ from astra_assistants.utils import env_var_is_missing, get_env_vars_for_provider
 logger = logging.getLogger(__name__)
 
 class AssistantManager:
-    def __init__(self, instructions: str, model: str = "gpt-4o", name: str = "managed_assistant", tools: List[ToolInterface] = None, thread_id: str = None, thread: str = None, assistant_id: str = None):
+    def __init__(self, instructions: str, model: str = "gpt-4o", name: str = "managed_assistant", tools: List[ToolInterface] = None, thread_id: str = None, thread: str = None, assistant_id: str = None, client = None):
         if tools is None:
             tools = []
         # Only patch if astra token is provided
-        if os.getenv("ASTRA_DB_APPLICATION_TOKEN") is not None:
-            self.client = patch(OpenAI())
+        if client is not None:
+            self.client = client
         else:
-            provider = get_llm_provider(model)[1]
-            env_vars = get_env_vars_for_provider(provider)
-            if env_var_is_missing(provider, env_vars):
-                raise Exception(f"Missing environment variables {env_vars}")
-            self.client = OpenAI()
+            if os.getenv("ASTRA_DB_APPLICATION_TOKEN") is not None:
+                self.client = patch(OpenAI())
+            else:
+                provider = get_llm_provider(model)[1]
+                env_vars = get_env_vars_for_provider(provider)
+                if env_var_is_missing(provider, env_vars):
+                    raise Exception(f"Missing environment variables {env_vars}")
+                self.client = OpenAI()
         self.model = model
         self.instructions = instructions
         self.tools = tools
@@ -124,7 +126,7 @@ class AssistantManager:
             print(e)
             raise e
         
-    async def run_thread(self, content, tool = None, thread_id: str = None, thread = None, additional_instructions = None) -> ToolOutput:
+    async def run_thread(self, content, tool = None, thread_id: str = None, thread = None, additional_instructions = None):
         if thread_id is not None:
             thread = self.client.beta.threads.retrieve(thread_id)
         elif thread is None:
