@@ -481,6 +481,8 @@ def get_headers_for_model(model):
             headers[AWS_REGION_NAME] = os.getenv("AWS_REGION_NAME")
         if provider != "openai":
             key = utils.get_api_key(provider, dynamic_key)
+        if provider == "openrouter":
+            key = os.getenv("OPENROUTER_API_KEY")
         if provider == "gemini":
             key = os.getenv("GEMINI_API_KEY")
         if provider == "ollama":
@@ -578,11 +580,16 @@ def enhance_copy_method(original_copy):
 def patch(client: Union[OpenAI, AsyncOpenAI]):
 
 
+    if client.api_key is not None and False:
+        pass
+
+
     if client.base_url == "https://api.openai.com/v1/":
         base_url = os.getenv("base_url") or os.getenv("BASE_URL", "https://open-assistant-ai.astra.datastax.com/v1")
         client.base_url=base_url
 
-    print(f"Patching OpenAI client, it will now communicate to Astra Assistants API: {client.base_url}\nLearn more about Astra at: {DOCS_URL}")
+    if os.getenv("ASTRA_ASSISTANTS_QUIET") is None:
+        print(f"Patching OpenAI client, it will now communicate to Astra Assistants API: {client.base_url}\nLearn more about Astra at: {DOCS_URL}")
 
     client_is_async = None
     if type(client) == OpenAIWithDefaultKey:
